@@ -7,8 +7,10 @@
   /* NQS license information */
 #include <nqs_generic/debug.h>
   /* debugging support */
-
+#include <nqs_generic/proto.h>
+  /* ANSI C prototypes */
 #include <stdio.h>
+#include <unistd.h>
 #include <sys/types.h>
 #include <nqs_req/nqs_req.h>
   /* Get definition of mid_t */
